X-Git-Url: https://git.saurik.com/bison.git/blobdiff_plain/e141f4d4bb6584bfbf13003047a2e48e9a6eab6a..e36ec1f41ffbe9f00db405c775201dbbc384c45c:/src/symlist.h
diff --git a/src/symlist.h b/src/symlist.h
index 3d439e85..03ffebef 100644
--- a/src/symlist.h
+++ b/src/symlist.h
@@ -1,6 +1,6 @@
/* Lists of symbols for Bison
- Copyright (C) 2002, 2005-2007, 2009-2010 Free Software Foundation,
+ Copyright (C) 2002, 2005-2007, 2009-2012 Free Software Foundation,
Inc.
This file is part of Bison, the GNU Compiler Compiler.
@@ -34,8 +34,8 @@ typedef struct symbol_list
* \c <>.
*/
enum {
- SYMLIST_SYMBOL, SYMLIST_TYPE,
- SYMLIST_DEFAULT_TAGGED, SYMLIST_DEFAULT_TAGLESS
+ SYMLIST_SYMBOL,
+ SYMLIST_TYPE
} content_type;
union {
/**
@@ -46,7 +46,7 @@ typedef struct symbol_list
/**
* The semantic type iff symbol_list::content_type = SYMLIST_TYPE.
*/
- uniqstr type_name;
+ semantic_type *sem_type;
} content;
location location;
@@ -88,11 +88,6 @@ symbol_list *symbol_list_sym_new (symbol *sym, location loc);
/** Create a list containing \c type_name at \c loc. */
symbol_list *symbol_list_type_new (uniqstr type_name, location loc);
-/** Create a list containing a \c <*> at \c loc. */
-symbol_list *symbol_list_default_tagged_new (location loc);
-/** Create a list containing a \c <> at \c loc. */
-symbol_list *symbol_list_default_tagless_new (location loc);
-
/** Print this list.
\pre For every node \c n in the list, n->content_type =
@@ -118,12 +113,8 @@ uniqstr symbol_list_n_type_name_get (symbol_list *l, location loc, int n);
/* Check whether the node is a border element of a rule. */
bool symbol_list_null (symbol_list *node);
-/** Set the \c \%destructor for \c node as \c code at \c loc. */
-void symbol_list_destructor_set (symbol_list *node, char const *code,
- location loc);
-
-/** Set the \c \%printer for \c node as \c code at \c loc. */
-void symbol_list_printer_set (symbol_list *node, char const *code,
- location loc);
+/** Set the \c \%destructor or \c \%printer for \c node as \c cprops. */
+void symbol_list_code_props_set (symbol_list *node, code_props_type kind,
+ code_props const *cprops);
#endif /* !SYMLIST_H_ */